@@ -125,7 +125,10 @@ class ProvisionStackTask(
                             if re.match(
                                 name_as_a_regex, provisioned_product.get("Name")
                             ):
-                                return f"SC-{self.account_id}-{provisioned_product.get('Id')}"
+                                pp_stack_name = aws.get_stack_name_for_pp_id(
+                                    servicecatalog, provisioned_product.get("Id")
+                                )
+                                return pp_stack_name
 
                     return self.stack_name
                 else:
@@ -145,7 +148,8 @@ class ProvisionStackTask(
                             return self.stack_name
                         else:
                             raise e
-                    return f"SC-{self.account_id}-{pp_id}"
+                    pp_stack_name = aws.get_stack_name_for_pp_id(servicecatalog, pp_id)
+                    return pp_stack_name
 
         elif self.stack_set_name != "":
             with self.spoke_regional_client("cloudformation") as cloudformation:
@@ -327,7 +331,10 @@ class ProvisionStackTask(
 
         task_output["provisioned"] = need_to_provision
         self.info(f"self.execution is {self.execution}")
-        if self.execution == constants.EXECUTION_MODE_HUB:
+        if self.execution in [
+            constants.EXECUTION_MODE_HUB,
+            constants.EXECUTION_MODE_SPOKE,
+        ]:
             self.info(
                 f"Running in execution mode: {self.execution}, checking for SSM outputs"
             )
